library photo_editor_pro;
import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:image_gallery_saver/image_gallery_saver.dart';
import 'package:photo_editor_pro/view/edit_view.dart';

class ImageEditorPage extends StatefulWidget {
  final List<Uint8List?> imageDataList;
  ImageEditorPage(this.imageDataList);

  @override
  State<ImageEditorPage> createState() => _ImageEditorPageState();
}

class _ImageEditorPageState extends State<ImageEditorPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        leading: IconButton(onPressed: () {
          Navigator.pop(context);
        },
            icon:Icon(Icons.arrow_back_outlined,color: Colors.white) ),
        backgroundColor: Colors.black,
        title: const Text("Image Editor",style: TextStyle(color: Colors.white),),
      ),
      body: SingleChildScrollView(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            for (var imageData in widget.imageDataList)
              if (imageData != null) Image.memory(imageData),
            const SizedBox(height: 16),
            ElevatedButton(
              child: const Text("Start editing"),
              onPressed: () async {
                var editedImage = await Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => ImageEditorNew(
                      image: widget.imageDataList.isNotEmpty ? widget.imageDataList.first : null,
                    ),
                  ),
                );

                // replace with edited image
                if (editedImage != null) {
                  widget.imageDataList[0] = editedImage;
                  setState(() {});
                }
              },
            ),
            ElevatedButton(
              child: const Text("Download Image"),
              onPressed: () async {
                // Assuming imageDataList has at least one image
                if (widget.imageDataList.isNotEmpty && widget.imageDataList[0] != null) {
                  await saveImage(widget.imageDataList[0]!);
                }
              },
            ),
            const SizedBox(height: 30),
          ],
        ),
      ),
    );
  }
  Future<void> saveImage(Uint8List imageData) async {
    final result = await ImageGallerySaver.saveImage(imageData);
    if (result['isSuccess']) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text("Image saved successfully")),
      );
    } else {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text("Failed to save image")),
      );
    }
  }

}
