library photo_editor_pro;
import 'dart:typed_data';
import 'package:croppy/croppy.dart';
import 'package:flutter/material.dart';
import 'package:photo_editor_pro/layers/setting_module.dart';
import 'dart:ui' as ui;

class NextScreen extends StatefulWidget {
  final Uint8List? imageData;

  const NextScreen({Key? key, required this.imageData}) : super(key: key);

  @override
  State<NextScreen> createState() => _NextScreenState();
}

class _NextScreenState extends State<NextScreen> {
  var _cropSettings = CropSettings.initial();
  ui.Image? _croppedImage;
  final _data = <int, CroppableImageData>{};

@override
  void initState() {
    // TODO: implement initState
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((_) {
      openBottom();
    });
  }
  openBottom() async {
    final newSettings = await showCropSettingsModal(
      context: context,
      initialSettings: _cropSettings,
    );
    setState(() {
      _cropSettings = newSettings;
    });
  }

  @override
  Widget build(BuildContext context) {

    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        backgroundColor: Colors.black,
        leading: IconButton(
          onPressed: () {
            Navigator.pop(context);
          },
          icon: const Icon(
            Icons.arrow_back_outlined,
            color: Colors.white,
          ),
        ),
        actions: [
          Padding(
            padding: const EdgeInsets.only(right: 15.0),
            child: GestureDetector(
              onTap: (){
                Navigator.pop(context, _croppedImage);
              },
              child: ClipRRect(
                borderRadius: BorderRadius.circular(10),
                child: Container(
                  height: MediaQuery.of(context).size.height * 0.04,
                  width: MediaQuery.of(context).size.width * 0.2,
                  color: Colors.white,
                  child: const Center(child: Text("Done")),
                ),
              ),
            ),
          ),
        ],
      ),
      body: Center(
        child: _croppedImage != null
            ? RawImage(image: _croppedImage)
            : Image(
                image: MemoryImage(widget.imageData!),
              ),
      ),
      floatingActionButtonLocation: FloatingActionButtonLocation.endDocked,
      floatingActionButton: Padding(
        padding: const EdgeInsets.only(bottom:15),
        child: FloatingActionButton(
          elevation: 0,
          backgroundColor:Colors.white ,
          onPressed: () {
            showMaterialImageCropper(
              context,
              locale: _cropSettings.locale,
              imageProvider: MemoryImage(widget.imageData!),
              heroTag: 'image-1',
              initialData: _data[0],
              cropPathFn: _cropSettings.cropShapeFn,
              enabledTransformations: _cropSettings.enabledTransformations,
              allowedAspectRatios: _cropSettings.forcedAspectRatio != null ? [_cropSettings.forcedAspectRatio!] : null,
              postProcessFn: (result) async {
                _croppedImage?.dispose();
                setState(() {
                  _croppedImage = result.uiImage;
                  _data[0] = result.transformationsData;
                });
                return result;
              },
            );
          },
          child: const Text("Crop" ,style:TextStyle(color: Colors.black,)),
        ),
      ),
    );
  }
}
