library photo_editor_pro;

import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:flutter_box_transform/flutter_box_transform.dart';
import 'package:photo_editor_pro/module/loading_screen.dart';
import 'package:screenshot/screenshot.dart';

class FrameView extends StatefulWidget {
  Uint8List image;

  FrameView({Key? key, required this.image}) : super(key: key);

  @override
  State<FrameView> createState() => _FrameViewState();
}

class _FrameViewState extends State<FrameView> {
  ScreenshotController screenshotController = ScreenshotController();

  List<String> frameList = [
    "assets/a2.png",
    "assets/a10.png",
    "assets/a11.png",
    "assets/a15.png",
    "assets/e3.png",
    "assets/e4.png",
    "assets/e5.png",
    "assets/frame2-removebg-preview.png",
    "assets/frame3-removebg-preview.png",
    "assets/frame4-removebg-preview.png",
    "assets/frame5-removebg-preview.png",
    "assets/frame6-removebg-preview.png",
    "assets/frame7-removebg-preview.png",
    "assets/frame8-removebg-preview.png",
    "assets/frame9-removebg-preview.png",
    "assets/frame10-removebg-preview.png",
    "assets/frame11-removebg-preview.png",
    "assets/frame12-removebg-preview.png",
    "assets/frame13-removebg-preview.png",
    "assets/frame17.png",
    "assets/frame18.png",
    "assets/frame19.png",
    "assets/frame20.png",
    "assets/frame21.png",
    "assets/frame22.png",
    "assets/1-removebg-preview.png",
    "assets/2-removebg-preview.png",
    "assets/3-removebg-preview.png",
    "assets/4-removebg-preview.png",
    "assets/5-removebg-preview.png",
    "assets/6-removebg-preview.png",
    "assets/7-removebg-preview.png",
    "assets/8-removebg-preview.png",
    "assets/9-removebg-preview.png",
    "assets/10-removebg-preview.png",
  ];
  List<String> selectedFrames = [];
  Map<String, Rect> framePositions = {};
  bool cropping = false;

  late Rect rect = Rect.fromCenter(
    center: MediaQuery.of(context).size.center(Offset.zero),
    width: 400,
    height: 300,
  );

  late Rect cropRect = rect;
  double _scale = 1.0;
  bool hideCornerHandles = false;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        leading: IconButton(
          onPressed: () {
            Navigator.pop(context);
          },
          icon: const Icon(Icons.arrow_back_outlined, color: Colors.white),
        ),
        backgroundColor: Colors.black,
        actions: [
          IconButton(
            padding: const EdgeInsets.symmetric(horizontal: 8),
            icon: const Icon(Icons.check, color: Colors.white),
            onPressed: () async {
              // Capture the screenshot
              loadingScreen.show();
              var data = await screenshotController.capture();
              loadingScreen.hide();
              if (mounted) Navigator.pop(context, data);
            },
          ),
        ],
      ),
      body: Center(
        child: Screenshot(
          controller: screenshotController,
          child: Stack(
            children: [
              GestureDetector(
                onTap: () {
                  print("tap");
                  print("hideCornerHandles-----$hideCornerHandles");
                  setState(() {
                    hideCornerHandles = !hideCornerHandles;
                  });
                },
                child: Image.memory(
                  widget.image,
                  height: MediaQuery.of(context).size.height,
                  width: MediaQuery.of(context).size.width,
                  fit: BoxFit.cover,
                ),
              ),
              for (var entry in framePositions.entries)
                TransformableBox(
                  key: ValueKey(entry.key),
                  rect: entry.value,
                  onChanged: (result, event) {
                    setState(() {
                      framePositions[entry.key] = result.rect;
                    });
                  },

                  sideHandleBuilder: (context, handle) {
                    return !hideCornerHandles
                        ? const SizedBox(
                      height: 2,
                      width: 0,
                    )
                        : Container();
                  },
                  contentBuilder: (BuildContext context, Rect rect, Flip flip) {
                    return DecoratedBox(
                      decoration: BoxDecoration(
                        border: !hideCornerHandles
                            ? Border.all(
                                color: Colors.blue,
                                width: 2,
                              )
                            : Border.all(
                                color: Colors.transparent,
                                width: 2,
                              ),
                        image: DecorationImage(
                          image: AssetImage(entry.key),
                          fit: BoxFit.fill,
                        ),
                      ),
                    );
                  },
                  cornerHandleBuilder: (context, handle) {
                    return !hideCornerHandles
                        ? DefaultCornerHandle(
                            handle: handle,
                            decoration: BoxDecoration(
                              color: Colors.white,
                              border: Border.all(
                                color: Colors.blue,
                                width: 2,
                              ),
                            ),
                          )
                        : Container();
                  },
                ),
            ],
          ),
        ),
      ),
      bottomNavigationBar: SafeArea(
        child: Container(
          color: Colors.black,
          height: 130,
          child: SingleChildScrollView(
            scrollDirection: Axis.horizontal,
            child: Row(
              children: [
                for (var frame in frameList)
                  GestureDetector(
                    onTap: () {
                      setState(() {
                        if (selectedFrames.contains(frame)) {
                          selectedFrames.remove(frame);
                          framePositions.remove(frame);
                        } else {
                          selectedFrames.add(frame);
                          framePositions[frame] = rect;
                        }
                        _scale = 1.0;
                      });
                    },
                    child: Container(
                      margin: const EdgeInsets.all(8.0),
                      decoration: BoxDecoration(
                        border: Border.all(
                          color: selectedFrames.contains(frame) ? Colors.white : Colors.transparent,
                          width: 2,
                        ),
                      ),
                      child: Image.asset(
                        frame,
                      ),
                    ),

                  ),
              ],
            ),
          ),
        ),
      ),

    );
  }
}
